RESEARCH NOTE

## USING THE LOAD-VELOCITY RELATIONSHIP FOR 1RM PREDICTION

BORIS JIDOVTSEFF, \[1,2\] NIGEL K. HARRIS, \[2\] JEAN-MICHEL CRIELAARD, \[1\] AND JOHN B. CRONIN \[2\]

1University of Liege, Department of Sports Sciences, Service of Training and Assessment of Physical Fitness, Liege, Belgium; and
2Institute of Sport and Recreation Research New Zealand, Auckland University of Technology, Auckland, New Zealand

ABSTRACT

Jidovtseff, B, Harris, NK, Crielaard, J-M, and Cronin, JB. Using

the load-velocity relationship for 1RM prediction. J Strength
Cond Res 25(1): 267–270, 2011—The purpose of this study

was to investigate the ability of the load-velocity relationship to
accurately predict a bench press 1 repetition maximum (1RM).
Data from 3 different bench press studies (n = 112) that

incorporated both 1RM assessment and submaximal load
velocity profiling were analyzed. Individual regression analysis

was performed to determine the theoretical load at zero
velocity (LD0). Data from each of the 3 studies were analyzed

separately and also presented as overall group mean.

Thereafter, correlation analysis provided quantification of the

relationships between 1RM and LD0. Practically perfect
correlations (r = ;0.95) were observed in our samples,

confirming the ability of the load-velocity profile to accurately

predict bench press 1RM.

KEY WORDS maximal strength, isoinertial, estimation

INTRODUCTION

etermination of an individual’s maximal strength
or 1 repetition maximum (1RM) is considered by
some authors to be problematic for populations

# D such as the young (18) and the aged (23). As

a result, different authors have reported methods that allow
the estimation of 1RM from performing submaximal
repetitions to failure (1,4,13,21,22). The repetitions to failure
method has been widely investigated, the consensus being
that the accuracy of these estimations depends on several
parameters such as the number of repetitions, type of
exercise, training background, and population used
(3,5,8,13,21). However, all these methods are based on the
force-endurance relationship and no author to our knowledge has proposed estimation of 1RM from the load-velocity
relationship. Given the increasing use of dynamometers such

Address correspondence to Boris Jidovtseff, <b.jidovtseff@ulg.ac.be>.

25(1)/267–270

Journal of Strength and Conditioning Research
� 2011 National Strength and Conditioning Association

as accelerometers and/or linear position transducers, it may
be that maximal strength can be predicted from the loadvelocity relationship within individuals. The aim of this study
was to first examine the relationship between 1RM and the
load-velocity profile and subsequently determine 1RM
prediction equations from that profile.

METHODS

Experimental Approach to the Problem
Theoretically, the load-velocity relationship could be used to
estimate maximal strength such as 1RM. The data of 3 studies
that determined both the 1RM and load-velocity relationship
for the bench press were used for analysis. The measurement
of average velocity (AV) at 3 or 4 increasing loads in these
studies determined, for each subject, the best fit regression line
and associated parameters such as slope and intercept point
on the Y axis that could be used for 1RM estimation.

Subjects
A total of 112 subjects (90 males, 22 females) from 3 previous
studies (14,15,17) were involved in this analysis. Table 1
summarizes the subject characteristics. All subjects were
involved in recreational activities and were free from any
injuries at the time of each investigation. Study protocols were
approved by the University of Liege Ethical Committee, and all
subjects signed an informed consent form prior to each study.

Equipment
A linear position transducer (Celesco Transducer Products,
Inc., model PT5DC, Chatsworth, California, USA) was used
to determine displacement-time data from which velocity
during a bench press (BP) exercise performed on a Smith
machine (Multipower M433, Salter S.A., Barcelona, Spain)
was derived. The equipment used in the present study has
been previously described (16).

Procedures
All subjects involved in each of the studies underwent the
same assessment procedures. The first session was dedicated
to familiarization with the bench press exercise, determination of the standardized position, and 1RM assessment
according to the standard methods established by Kraemer
and Fry (19). The bench press exercise was a concentric-only
movement and started with the barbell 3 cm above the
subject’s nipple line. Hand position on the bar was defined as

VOLUME 25 | NUMBER 1 | JANUARY 2011 | 267

Copyright © National Strength and Conditioning Association Unauthorized reproduction of this article is prohibited.

Using the Load-Velocity Relationship for 1RM Prediction

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

the distance measured between elbows at 90 degrees of
shoulder abduction. During the whole movement, subjects
had to keep the back on the bench and their hips flexed at
90 degrees. During the second session, which occurred
approximately 1 week after the initial 1RM assessment, all
subjects were tested at 3 or 4 increasing bench press loads, as
presented in Table 1. The number of trials performed at each
load was as follows: 4 trials at 30, 35, and 40% 1RM; 3 trials at **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**
50, 60, and 70% 1RM; and 2 trials at 80, 90, and 95% 1RM.
For each load, subjects were instructed to lift the barbell as
fast as possible, but they were not allowed to release the bar.
The best trial was selected for analysis in terms of the highest
velocity value. Average velocity (AV) was measured for the
entire concentric phase of each bench press. Intertrial and
intersession reliability of this parameter has been demonstrated to be very good during concentric bench press
assessment (coefficient of variation \[CV\],7%) (16).

Data Analysis
Data were sampled at 1,000 Hz via an analogue-to-digital
interface (PCMCIA DAQCard,
6024E, National Instrument,
Austin, Texas, USA). Labview
software (National Instrument)
enabled data analysis, storage of
information, and instantaneous
presentation of results. Velocity
was derived from the displacement signal with the 2nd Order
Central method. A low-pass
filter was used to smooth velocity data with a low cut-off
of 17Hz.

software (Microsoft, Redmond, Washington, USA). From
this linear regression, the slope (SLP), theoretical AV at 0 kg
(AV0), and theoretical load at 0 m/s \[2\]\[1\] (LD0) were calculated.
Mean values and standard deviation of these data were then
used to describe the change in average velocity with increasing relative load. The accuracy of the prediction formula was
calculated using the standard error of estimate as follows:

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

f
**f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f**

- Yð � YÞ \[2\]

N

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

SEE ¼

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

s

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

The magnitudes of the relationships between actual and
predicted 1RM were interpreted using Pearson correlation
coefficients, described as trivial (0.0–0.1), low (0.1–0.3),
moderate (0.3–0.5), high (0.5–0.7), very high (0.7–0.9), or
practically perfect (0.9–1.0) (6,12). An inference about the
true (large-sample) value of a correlation was based on
uncertainty in its magnitude (2); if the 90% confidence limits
overlapped substantial positive and negative values, the

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Statistical Analyses
Means and standard deviations
are used throughout as measures of centrality and spread of
data. For each subject the bestfit regression line was plotted
through the known load (X)
and AV (Y) values using Excel

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

268 Journal of Strength and Conditioning Researchthe TM

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Copyright © National Strength and Conditioning Association Unauthorized reproduction of this article is prohibited.

Journal of Strenthe gth and Conditioning ResearchTM

| \<www.nsca-jscr.org>

magnitude was deemed unclear; otherwise the magnitude
was deemed to be the observed magnitude. The confidence
interval was derived via the Fisher z transformation (11); for
trivial-small correlations the confidence limits were ;60.15.
Thus the power of this study was such that only correlations
greater than .0.25 or,20.25 were considered clear. Given
the bipolar nature of male and female values that artificially
inflate correlation coefficients, the strength of the relationships was expressed for each sample.

RESULTS

For the whole population, bench press 1RM was 60 6 19 kg.
Mean and standard deviation for the SLP, AV0, and LD0
were, respectively: 20.028 6 0.012 m�s \[2\]\[1\] �kg \[2\]\[1\], 1.70 6
0.13 m�s \[2\]\[1\], and 70 6 22 kg.

LD0 corresponded to 116 6 8% of the 1RM. Figure 1
illustrates the mean linear regression between AVand relative
load. AV at 1RM was 0.23 6 0.09 m�s \[2\]\[1\] .

The correlations between 1RM and load at zero velocity
are illustrated in Figure 2. The correlations were practically
perfect for study 1 (r = 0.96), study 2 (r = 0.95), and study 3
(r = 0.95). The cumulative correlation for the entire sample
was r = 0.98.

DISCUSSION

Our results confirmed that the load-velocity relationship can
be used to estimate maximal strength performance (i.e.,
1RM). We chose to analyze the AV rather than the peak
velocity for 2 reasons. First, AV better represents the ability of
the subject to move the load throughout the entire concentric
phase. Second, as previously demonstrated in concentric
bench press assessment (16), AV decreases linearly with
increasing load, making mathematical analysis easier.

The analysis of the AV-relative load relationship revealed
that the movement velocity associated with 1RM is 0.23 6
0.09 m�s \[2\]\[1\] and LD0 corresponds to 116 6 8% of the
1RM. The results support findings that maximum isometric

force is greater than the maximum concentric force (10) as
per the force-velocity relationship of muscle. In addition, it is
well known that the 1RM

corresponds to the highest load
that can be lifted for the whole

concentric phase and therefore
depends on the strength developed in the weakest position.
In the bench press this position, also called the ‘‘sticking
region,’’ occurs at approximately 10 to 15 cm above the
chest (9,20). The assessment of
velocity or acceleration at that
position may be interesting
because the bar should be close
to zero when a subject reaches his or her 1RM.

A practically perfect correlation between LD0 and the
1RM (r = 0.98) was found, providing evidence that the loadvelocity relationship may be used to estimate 1RM using the
following equation:

1RM ¼ ð0:871LD0Þ � 0:624 ðequation 1Þ

This formula offers a reasonable prediction of the 1RM
with a standard error of estimate (SEE) of 4 kg (7%). This
approach of using the load-velocity relationship to predict
maximal isoinertial strength appears to be at least as accurate
as the repetitions to failure method. According to the review
of Pereira and Gomes (22), predicting 1RM from maximum
repetition tests results in fairly good correlations (r . 0.68).
However, the number of repetitions and the relative load
used appear critical to ensure accuracy. Prediction with 10 or
fewer repetitions has resulted in correlations of greater than
0.9 between the predicted and actual 1RMs and SEE,10 kg
(22). Cosgrove and Mayhew (7) reported that light-load
endurance tests lead to less accurate prediction of 1RM.
Hence, it is generally recommended that heavier (75% 1RM
and higher) loads be used for the most accurate prediction of
1RM from submaximal load testing (24). In our study, even
when we estimated the 1RM with 2 submaximal loads
(30–35% and 70% for S1 and S3; 40 and 60% for S2), the
correlation between LD0 and 1RM was practically perfect
(r = 0.96) and the SEE did not exceed 5 kg.

It appears that the prediction of bench press 1 RM from the
load-velocity relationship is just as accurate as the repetition
to failure method; however, the former method can use
lighter loads and does not require lifting to failure, which may
be suitable for a broader range of populations. Clearly, further
research is needed to explore the ability of the load-velocity
relationship to predict 1RM in other exercises. Moreover, this
method appears of great interest because it can be used
concurrently for 1RM prediction and velocity/power profiling

VOLUME 25 | NUMBER 1 | JANUARY 2011 | 269

Copyright © National Strength and Conditioning Association Unauthorized reproduction of this article is prohibited.

Using the Load-Velocity Relationship for 1RM Prediction

at submaximal loads. Such an approach is an intuitively
appealing strategy for athlete assessment and monitoring. The
major limitation of this method is the necessity of inertial
dynamometers such as linear position transducers or accelerometers, however, with time we believe the use of such technology will be commonplace in most weight training facilities.

PRACTICAL APPLICATIONS

We recommend that strength and conditioning practitioners
who want to estimate bench press 1RM from the AV-load
relationship need to measure AV at 3 or 4 increasing loads,
starting with a light load. The load increment may be
customized. It is unnecessary to use very heavy loads, but
the decrease in AV between the lightest and heaviest loads
should reach at least 0.5 m�s \[2\]\[1\] to significantly cover the loadvelocity relationship. The consequent linear regression
allows the calculation of LD0 and subsequently the
estimation of 1RM by using equation 1. To get the subject’s
best performance, it is recommended that 3 to 5 separate
trials be performed at each load and a full recovery period be
allowed between trials given.

ACKNOWLEDGMENT

No funding was received for this research.

REFERENCES

1. Abadie, BR and Wentworth, MC. Prediction of one repetition

maximal strength from a 5-10 repetition submaximal strength test in
college-aged females. J Exerc Physiol 4: 1–6, 2000.

2. Batterham, AM and Hopkins, WG. Making meaningful inferences

about magnitudes. Int J Sports Physiol Perf 1: 50–57, 2006.

3. Becque, M and Pick, J. Validity of predicting 1RM and %1RM in

weight-trained and untrained males. Med Sci Sports Exerc 27: S10,
1995\.

4. Berger, RA. Determination of the resistance load for 1RM and

10RM. J Assoc Phys Mental Rehab 15: 108–110, 1961.

5. Braith, R, Graves, J, Leggett, S, and Pollock, M. Effect of training on

the relationship between maximal and submaximal strength. Med Sci
Sports Exerc 25: 132–138, 1993.

6. Cohen, J. Statistical Power Analysis for the Behavioural Sciences. (2nd

ed.). Hillsdale, NJ: Lawrence Erlbaum, 1988.

7. Cosgrove, L and Mayhew, JL. A modified YMCA bench press test to

predict strength in adult women. IAHPERD J 30: 25–26, 1997.

8. Dohoney, P, Chromiak, JA, Lemire, D, Abadie, B, and Kovacs, C.

Prediction of one repetition maximum (1-RM) strength from a 4–6

RM and a 7–10 RM submaximal strength test in healthy young adult
males. J Exerc Physiol 5: 54–59, 2002.

9. Elliott, BC, Wilson, GJ, and Kerr, GK. A biomechanical analysis of

the sticking region in the bench press. Med Sci Sports Exerc 21: 450–
462, 1989.

10. Enoka, RM. Neuromechanics of Human Movement. Champaign, IL:

Human Kinetics, 2002.

11. Fisher, RA. On the probable error of a coefficient of correlation

deduced from a small sample. Metron 1: 3–32, 1921.

12. Hopkins, WG. A scale of magnitudes for effect statistics. Available at:

<http://www.sportsci.org/resource/stats/index.html>. Accessed
2002\.

13. Horvat,M,Ramsey,V,Franklin,C,Gavin,C,Palumbo,T,andGlass,LA.

A method for predicting maximal strength in collegiate women
athletes. J Strength Cond Res 17: 324–328, 2003.

14. Jidovtseff, B, Cordonnier, C, Vandermeulen, M, and Crielaard, JM.

Gender differences in force-power-velocity relationships. Isokinetics
Exerc Sci 16: 196, 2008.

15. Jidovtseff, B, Cordonnier, C, Binard, AS, Rulot, P, Maquet, D,

Croisier, JL, Demoulin, C, and Crielaard, JM. Relevance of inertial
fatigue test in sport applications. Isokinetics Exerc Sci 16: 190, 2008.

16. Jidovtseff, B, Croisier, JL, Lhermerout, C, Serre, L, Sac, D, and

Crielaard, JM. The concept of iso-inertial assessment: Reproducibility analysis and descriptive data. Isokinetics Exerc Sci 14: 53–62,
2006\.

17. Jidovtseff, B, Quie\`vre, J, Hanon, C, and Crielaard, JM. Les profils

musculaires inertiels permettent une de´finition plus pre´cise des
charges d’entraıˆnement. Sci Sports 24: 91–96, 2009.

18. Kraemer, WJ and Fleck, SJ. Strength Training for Young Athletes

(2nd ed.). Champaign, IL: Human Kinetics, 2005.

19. Kraemer, WJ and Fry, AC. Strength testing: Development and

evaluation of methodology. In: Physiological Assessment of Human
Fitness. Maud, J and Foster, C, eds. Champaign, IL: Human Kinetics,
1995\. pp. 115–138.

20. Madsen, N and McLaughlin, T. Kinematic Factors Influencing

Performance and Injury Risk in the Bench Press Exercise. Med Sci
Sports Exerc 16: 376–381, 1984.

21. Mayhew, JL, Prinster, JL, Ware, JS, Zimmer, DL, Arabas, JR, and

Bemben, MG. Muscular Endurance Repetitions to Predict Bench
Press Strength in Men of Different Training Levels. J Sports Med Phys
Fitness 35: 108–113, 1995.

22. Pereira, MI and Gomes, PS. Muscular strength and endurance tests:

Reliability and prediction of one repetition maximum—Review and
new evidences. Revista Brasileira de Medicina do Esporte 9: 336–46,
2003\.

23. Pollock, ML and Evans, WJ. Resistance training for health and

disease: Introduction. Med Sci Sports Exerc 31: 10–11, 1999.

24. Ware, J, Clemens, C, Mayhew, J, and Johnston, T. Muscular

endurance repetitions to predict bench press and squat strength in
college football players. J Strength Cond Res 9: 99–103, 1995.

270 Journal of Strength and Conditioning Researchthe TM

Copyright © National Strength and Conditioning Association Unauthorized reproduction of this article is prohibited.
